@@ -11,7 +11,7 @@ package Dist::Zilla::Plugin::Git::CheckFor::CorrectBranch;
 BEGIN {
   $Dist::Zilla::Plugin::Git::CheckFor::CorrectBranch::AUTHORITY = 'cpan:RSRCHBOY';
 }
-$Dist::Zilla::Plugin::Git::CheckFor::CorrectBranch::VERSION = '0.010';
+$Dist::Zilla::Plugin::Git::CheckFor::CorrectBranch::VERSION = '0.011';
 # ABSTRACT: Check that you're on the correct branch before release
 
 use Moose;
@@ -68,8 +68,8 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Chris Weyl Christian Walde <walde.christian@googlemail.com> Karen Etheridge
-<ether@cpan.org> Mike Doherty <doherty@cs.dal.ca> Olivier Mengué
+=for :stopwords Chris Weyl Christian Walde Karen Etheridge Mike Doherty Olivier Mengué
+<walde.christian@googlemail.com> <ether@cpan.org> <doherty@cs.dal.ca>
 <dolmen@cpan.org>
 
 =head1 NAME
@@ -78,7 +78,7 @@ Dist::Zilla::Plugin::Git::CheckFor::CorrectBranch - Check that you're on the cor
 
 =head1 VERSION
 
-This document describes version 0.010 of Dist::Zilla::Plugin::Git::CheckFor::CorrectBranch - released April 11, 2014 as part of Dist-Zilla-PluginBundle-Git-CheckFor.
+This document describes version 0.011 of Dist::Zilla::Plugin::Git::CheckFor::CorrectBranch - released April 11, 2014 as part of Dist-Zilla-PluginBundle-Git-CheckFor.
 
 =head1 SYNOPSIS
 
